@@ -96,7 +96,6 @@ class Action:
         :param action: action method
         :return: Action instance
         """
-        # todo catch, passthrough, or assign args and kwargs
         # todo consider logging that a new action has been registered
         # catch class instance
         if isinstance(action, Action):
@@ -285,7 +284,7 @@ class ConfiguredAction:
 
 class TrackedAction(ConfiguredAction):
     def __init__(self,
-                 action: Union[Callable, ConfiguredAction],
+                 action: Union[str, Callable, ConfiguredAction],
                  *args,
                  **kwargs,
                  ):
@@ -382,6 +381,8 @@ class TrackedAction(ConfiguredAction):
             if self.action.error is True:
                 out['error_during_execution'] = True
                 out['error_details'] = self.action.error_details
+            else:  # if completed and no error, include the method return
+                out['action_return'] = self.method_return
         return out
 
     @classmethod
