@@ -5,9 +5,11 @@ import logging
 import bisect
 import datetime
 import uuid
+import copy
 from typing import List, Union, Iterable
 from .timepoint import ActionTimePoint
 from .action import Action, ConfiguredAction
+from .sequencing import ActionList
 
 logger = logging.getLogger(__name__)
 
@@ -24,6 +26,9 @@ class SamplingScheduler(object):
 
     UUID_PREFIX = 'sched-'
 
+    # class-level list of default actions
+    default_actions: ActionList = ActionList()
+
     def __init__(self,
                  *actions: Union[str, callable, Action],
                  time_deltas: List[float] = None,
@@ -46,7 +51,12 @@ class SamplingScheduler(object):
         self._killswitch = threading.Event()
 
         # store default actions
-        self._default_actions: List[ConfiguredAction] = []
+        if len(actions) > 0:
+            # todo consider whether this should override or extend
+            self.instance_default_actions: ActionList = ActionList(*actions)
+        else:
+            # todo consider how to extend default list
+            self.instance_default_actions: ActionList = copy.copy(self.default_actions)
 
         # time stamp for Scheduler creation
         self.created = time.time()
@@ -68,12 +78,6 @@ class SamplingScheduler(object):
         # store experiment name for reference
         self.sequence_name: str = sequence_name
 
-        if actions is not None:
-            if type(actions) not in [list, tuple]:
-                actions = [actions]
-            for action in actions:
-                self.add_default_action(action)
-
         # append instance
         self.instances.append(self)
         # todo implement databasing
@@ -100,11 +104,6 @@ class SamplingScheduler(object):
         """uuid4 for the scheduler"""
         return self.UUID_PREFIX + self._uuid
 
-    @property
-    def actions(self) -> List[callable]:
-        """list of actions which the scheduler will perform when triggered"""
-        return self._default_actions
-
     @property
     def started(self) -> bool:
         """whether the sequence has been started"""
@@ -194,16 +193,10 @@ class SamplingScheduler(object):
         except IndexError:
             raise IndexError(f'The {cls.__name__} has no instances. ')
 
-    @property
-    def default_actions(self) -> List[ConfiguredAction]:
-        """list of default actions associated with the Scheduler"""
-        # todo have default actions at the scheduler class level
-        return self._default_actions
-
     def _determine_actions(self,
                            additional_actions: Iterable[Union[str, callable, ActionTimePoint]] = None,
                            specified_actions: Iterable[Union[str, callable, ActionTimePoint]] = None,
-                           ):
+                           ) -> ActionList:
         """
         Determines the actions for a time point. If no actions are provided, the default actions of the
         instance are used. If additional actions are provided, those actions will be performed in addition to the
@@ -217,13 +210,12 @@ class SamplingScheduler(object):
         """
         # establish list of actions
         if additional_actions is not None:
-            actions = []
-            actions.extend(self._default_actions)
+            actions = copy.copy(self.instance_default_actions)
             actions.extend(additional_actions)
         elif specified_actions is not None:
-            actions = specified_actions
+            actions = ActionList(*specified_actions)
         else:
-            actions = self._default_actions
+            actions = copy.copy(self.instance_default_actions)
         return actions
 
     def trigger(self,
@@ -323,47 +315,6 @@ class SamplingScheduler(object):
             while self.busy is True:
                 time.sleep(0.5)
 
-    def add_default_action(self,
-                           action: Union[str, callable, Action, ConfiguredAction],
-                           # location: int = None,  # todo add support for order specification (location)
-                           ):
-        """
-        Adds a callable action to the list of actions
-
-        :param action: action method to execute on triggering
-        """
-        # perform callable check
-        if callable(action) is False:
-            raise TypeError(f'The provided action {action} is not callable.')
-
-        # if not a configured action, create instance
-        if isinstance(action, ConfiguredAction) is False:
-            action = ConfiguredAction(action)
-
-        self._default_actions.append(
-            action
-        )
-        for tp in self._time_points:
-            if tp.triggered is False:
-                tp.add_action(action)
-
-    def remove_default_action(self,
-                              action: Union[str, callable, Action],
-                              ) -> callable:
-        """
-        Removes the specified action from the list of actions
-
-        :param action: action to remove
-        :return: removed action
-        """
-        action = Action.register_action(action)
-        if action not in self._default_actions:
-            raise ValueError(f'The action {action} is not in the list of actions')
-        for tp in self._time_points:
-            if tp.triggered is False:
-                tp.remove_action(action)
-        return self._default_actions.remove(action)
-
     def insert_time_point(self,
                           time_delta: float = None,
                           position: int = -1,
@@ -539,7 +490,8 @@ class SamplingScheduler(object):
         out = {
             'uuid': self.uuid,
             'sequence_name': self.sequence_name,
-            'actions': [action.name for action in self.actions],
+            'instance_default_actions': [action.name for action in self.instance_default_actions],
+            'class_default_actions': [action.name for action in self.default_actions],
             'started': self.started,
             'created': self.created,
             'num_time_points': len(self.time_points),
