@@ -4,7 +4,8 @@ import threading
 import logging
 import time
 from typing import Union, List, Dict, Callable
-from .action import TrackedAction, Action, ConfiguredAction
+from .action import Action, ConfiguredAction
+from .sequencing import ActionList, ConfiguredActionList, TrackedActionList
 
 
 logger = logging.getLogger(__name__)
@@ -129,7 +130,11 @@ class ActionTimePoint(TimePoint):
     def __init__(self,
                  time_delta: float,
                  name: str = None,
-                 actions: List[Union[Callable, Action, ConfiguredAction]] = [],
+                 actions: Union[
+                     List[Union[str, Callable, Action, ConfiguredAction]],
+                     ActionList,
+                     ConfiguredActionList,
+                 ] = [],
                  **action_kwargs,
                  ):
         """
@@ -150,22 +155,19 @@ class ActionTimePoint(TimePoint):
             name=name,
         )
         # store actions for timepoint
-        self._actions: List[TrackedAction] = [
-            TrackedAction(action) for action in actions
-        ]
+        self.actions = TrackedActionList(*actions)
+
         # update kwargs
         for action_name in action_kwargs:
-            for action in self._actions:
+            for action in self.actions:
                 if action.name == action_name:
                     action.update_kwargs(**action_kwargs[action_name])
         # internal storage attributes
         self._triggered = False
         self._thread: threading.Thread = None
         self._lock: threading.Lock = threading.Lock()
-        # todo create attribute for retrieving action returns
 
     def __str__(self):
-        # todo add attribute for retrieving formatted time (HH:MM:SS)
         out = f'{self.__class__.__name__} {self.string_time_delta}'
         if self.complete is True:
             out += ' COMPLETE'
@@ -176,30 +178,6 @@ class ActionTimePoint(TimePoint):
     def __call__(self, **kwargs):
         self.trigger(**kwargs)
 
-    @property
-    def actions(self) -> List[TrackedAction]:
-        """actions to be run when the timepoint is called"""
-        return self._actions
-
-    def add_action(self,
-                   action: Union[str, Callable, Action, ConfiguredAction],
-                   location: int = None,
-                   ):
-        """
-        Adds an action to the timepoint. Actions will be executed in the order they appear in the list of actions for
-        the ActionTimePoint instance.
-
-        :param action: action to perform. Actions may be added by providing a callable method or name of a predefined
-            callable method
-        :param location: index location to insert. If left as None the action will be appended
-        """
-        if location is None:
-            location = len(self._actions)
-        self._actions.insert(
-            location,
-            TrackedAction(action),
-        )
-
     def remove_action(self,
                       action: Union[str, Callable, Action],
                       ):
@@ -213,8 +191,6 @@ class ActionTimePoint(TimePoint):
         # todo implement
         #   - determine identifier
         #   - remove from _actions list
-        # todo implement ability to change action associated with time points
-        #   - e.g. switch from no pump ON/OFF to method with pump on/off
 
     def _execute_actions(self, **kwargs):
         """
@@ -253,6 +229,7 @@ class ActionTimePoint(TimePoint):
         :param kwargs: keyword arguments for the actions. Keyword arguments will be passed through to their respective
             methods.
         """
+        # todo consider refactoring to simply add a time point at current time
         if self.triggered is True:
             raise SystemError(f'Multiple executions of the same {self.__class__.__name__} are not supported')
         # todo catch multiple calls and raise
