@@ -62,7 +62,7 @@ class TestActionTimePoint(unittest.TestCase):
         atp = ActionTimePoint(
             3.,
         )
-        atp.add_action(fifty_ms)
+        atp.actions.append(fifty_ms)
         atp.trigger()
         atp.wait_for_completion()
         self.assertRaises(
@@ -80,7 +80,7 @@ class TestActionTimePoint(unittest.TestCase):
 
     def test_flags(self):
         atp = ActionTimePoint(3)
-        atp.add_action(one_second)
+        atp.actions.append(one_second)
         atp.trigger()
         self.assertTrue(
             atp.in_progress
